#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import matplotlib.pyplot as plt

import sys
import os
import math
import numpy as np

sys.path.append('../')
sys.path.append('../redcp/hexapod_robot')

from redcp import * # import data types
import HexapodRobot as hexapod #import hexapod robot
 
from HexapodController import Controller

def plot_robot_path(path):
    fig, ax = plt.subplots()
    path.plot(ax, 30)
    plt.xlabel('x[m]')
    plt.ylabel('y[m]')
    plt.axis('equal')
    plt.show()

if __name__=="__main__":
    robot = hexapod.HexapodRobot(Controller())
    robot.turn_on() #turn on the robot 
    robot.start_navigation() #start navigation thread
    
    goals = [ #assign goal for navigation
        Pose(Vector3(1, -1, 0), Quaternion(1, 0, 0, 0)), 
        Pose(Vector3(1, 1, 0), Quaternion(1, 0, 0, 0)), 
        Pose(Vector3(-1, 0, 0), Quaternion(1, 0, 0, 0)), 
        Pose(Vector3(-3, 0, 0), Quaternion(1, 0, 0, 0)), 
    ]

    path = Path()
    for goal in goals: #go from goal to goal
        robot.goto(goal)
        while robot.navigation_goal is not None:
            if robot.odometry_ is not None: #sample the current odometry
                path.poses.append(robot.odometry_.pose)
                odom = robot.odometry_.pose #check the robot distance to goal
                odom.position.z = 0 #compensate for the height of the robot as we are interested only in achieved planar distance 
                dist = goal.dist(odom) #calculate the distance
                sys.stdout.write("\r[t1a-ctrl] actual distance to goal: %.2f" % dist)
            time.sleep(0.1) #wait for a while
        print("\n[t1a-ctrl] distance to goal: %.2f" % dist)
    robot.stop_navigation()
    robot.turn_off()
    plot_robot_path(path)
